NIGH_3024 = "3024-night"
A11Y_DARK = "a11y-dark"
BLACKBOARD = "blackboard"
BASE_16_DARK = "base16-dark"
BASE_16_LIGHT = "base16-light"
COBALT = "cobalt"
DRACULA = "dracula"
DUOTONE = "duotone-dark"
HOPSCOTCH = "hopscotch"
LUCARIO = "lucario"
MATERIAL = "material"
MONOKAI = "monokai"
NIGHT_OWL = "night-owl"
NORD = "nord"
OCEANIC_NEXT = "oceanic-next"
ONE_DARK = "one-dark"
ONE_LIGHT = "one-light"
PANDA = "panda-syntax"
PARAISO = "paraiso-dark"
SETI = "seti"
SHADES_OF_PURPLE = "shades-of-purple"
SOLARIZED_DARK = "solarized dark"
SOLARIZED_LIGHT = "solarized light"
SYNTHWAVE_84 = "synthwave-84"
TOMORROW_NIGHT = "tomorrow-night-bright"
TWILIGHT = "twilight"
VERMINAL = "verminal"
VSCODE = "vscode"
YETI = "yeti"
ZENBURN = "zenburn"
